@@ -59,7 +59,6 @@ where
     waitings: BinaryHeap<Waiting<T>>,
 }
 
-#[derive(Clone, Copy)]
 pub struct TimewrapHandle<'a, T, S>
 where
     T: Time,
@@ -67,6 +66,19 @@ where
     target: &'a Timewrap<T, S>,
 }
 
+impl<'a, T, S> Clone for TimewrapHandle<'a, T, S>
+where
+    T: Time,
+{
+    fn clone(&self) -> Self {
+        Self {
+            target: self.target,
+        }
+    }
+}
+
+impl<'a, T, S> Copy for TimewrapHandle<'a, T, S> where T: Time {}
+
 impl<'a, T, S> Deref for TimewrapHandle<'a, T, S>
 where
     T: Time,
